@@ -488,53 +488,56 @@ savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last)
 	pid = 0;
 #endif
 
-if (pid == 0) { /* this is the child */
-	lp = log_file_create (logfile, type, logw->columns, fields, widths);
-	k = 0;
-	if (lp)
-	{
-		model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
-		exported = last - first + 1;
-		/* create an array to be used for sorting */
-		sorteditems = g_new0 (item_t, exported);
-		/* go through the QSO's and store in the sort array */
-		for (i = logw->qsos - first; i >= logw->qsos - last; i--)
+	if (pid == 0)
+	{ /* this is the child */
+		lp = log_file_create (logfile, type, logw->columns, fields, widths);
+		k = 0;
+		if (lp)
 		{
-			pathstr = g_strdup_printf ("%d", i);
-			path = gtk_tree_path_new_from_string (pathstr);
-			gtk_tree_model_get_iter (model, &iter, path);
-			for (j = 0; j < logw->columns; j++)
+			model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
+			exported = last - first + 1;
+			/* create an array to be used for sorting */
+			sorteditems = g_new0 (item_t, exported);
+			/* go through the QSO's and store in the sort array */
+			for (i = logw->qsos - first; i >= logw->qsos - last; i--)	
 			{
-				gtk_tree_model_get (model, &iter, logw->logfields[j], &sorteditems[k][fields[j]], -1);
-if (fields[j] == DATE || fields[j] == NAME || fields[j] == QTH || fields[j] == U1 || fields[j] == U2 || fields[j] == REMARKS)
-	sorteditems[k][fields[j]] = g_locale_from_utf8 (sorteditems[k][fields[j]], -1, NULL, NULL, NULL);
+				pathstr = g_strdup_printf ("%d", i);
+				path = gtk_tree_path_new_from_string (pathstr);
+				gtk_tree_model_get_iter (model, &iter, path);
+				for (j = 0; j < logw->columns; j++)
+				{
+					gtk_tree_model_get (model, &iter, logw->logfields[j], &sorteditems[k][fields[j]], -1);
+					if (fields[j] == DATE || fields[j] == NAME || fields[j] == QTH || fields[j] == U1 || fields[j] == U2 || fields[j] == REMARKS)
+						sorteditems[k][fields[j]] = g_locale_from_utf8 (sorteditems[k][fields[j]], -1, NULL, NULL, NULL);
+				}
+				k++;
+				gtk_tree_path_free (path);
+				g_free (pathstr);
 			}
-			k++;
-			gtk_tree_path_free (path);
-			g_free (pathstr);
-		}
+	
+			if (type == TYPE_LABELS)
+			{
+				if (preferences.tsvsortbydxcc)
+					qsort(sorteditems, exported, sizeof(gchar*)*QSO_FIELDS, &savelog_compar_sortbydxcc);
+				else if (preferences.tsvgroupbycallsign > 1)
+					qsort(sorteditems, exported, sizeof(gchar*)*QSO_FIELDS, &savelog_compar_groupbycall);
+			}
+	
+			/* QSO's have been sorted (or not), now save them */
 
-		if (type == TYPE_LABELS)
-		{
-			if (preferences.tsvsortbydxcc)
-				qsort(sorteditems, exported, sizeof(gchar*)*QSO_FIELDS, &savelog_compar_sortbydxcc);
-			else if (preferences.tsvgroupbycallsign > 1)
-				qsort(sorteditems, exported, sizeof(gchar*)*QSO_FIELDS, &savelog_compar_groupbycall);
-		}
+			for (i = 0; i <= exported -1; i++)
+				log_file_qso_append (lp, sorteditems[i]);
+			/* free the sortarray */
+			g_free(sorteditems);
 
-		/* QSO's have been sorted (or not), now save them */
-		for (i = 0; i <= exported -1; i++)
-			log_file_qso_append (lp, sorteditems[i]);
-		/* free the sortarray */
-		g_free(sorteditems);
-
-		log_file_close (lp);
+			log_file_close (lp);
 #ifndef G_OS_WIN32
-		_exit (0);
+			_exit (0);
 #else
-		return;
+			return;
 #endif
-	} }
+		}
+	}
 	/* parent running */
 #ifndef G_OS_WIN32
 	g_timeout_add (1000, (GSourceFunc) childcheck, NULL);
